<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class PagesPortfolio extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'pages-portfolio';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Pages - Portfolio Widget', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'pages' ];
	}

	public function get_keywords() {
		return [ 'Portfolio', 'carousel' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_portfolio',
			[
				'label' => esc_html__( 'Portfolio Area', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'image',
			[
				'label'   => esc_html__( 'Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add Your Image', 'bdevs-elementor' ),
			]
		);
		
		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'sub_heading',
			[
				'label'       => __( 'Sub Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your sub heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
            'post_number',
            [
                'label'       => __( 'Post Number', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Post Number', 'bdevs-elementor' ),
                'default'     => __( '4', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'post_order',
            [
                'label'     => esc_html__( 'Post Order', 'bdevs-elementor' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'asc'  => esc_html__( 'ASC', 'bdevs-elementor' ),
                    'desc' => esc_html__( 'DESC', 'bdevs-elementor' ),
                ],
                'default'   => 'asc',
            ]
        );

		$this->end_controls_section();



		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'center',
			]
		); 

		$this->add_control(
			'show_image',
			[
				'label'   => esc_html__( 'Show Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->add_control(
			'show_heading',
			[
				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->add_control(
			'show_sub_heading',
			[
				'label'   => esc_html__( 'Show Sub Heading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display();
		?>

		<?php if (( '' !== $settings['image']['url'] ) && ( $settings['show_image'] )): ?>
			<section class="banner-header banner-img section-padding valign bg-img bg-fixed" data-overlay-darkgray="2" data-background="<?php echo wp_kses_post($settings['image']['url']); ?>"></section>
		<?php endif; ?>
		<!-- Projects section -->
		<section class="section-padding2">
			<div class="container">
				<div class="row">
					<div class="col-md-12 text-center mb-30 animate-box" data-animate-effect="fadeInUp">
						<?php if (( '' !== $settings['sub_heading'] ) && ( $settings['show_sub_heading'] )): ?>
						<div class="section-subtitle"><?php echo wp_kses_post($settings['sub_heading']); ?></div>
					<?php endif; ?>
					<?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )): ?>
					<div class="section-title"><?php echo wp_kses_post($settings['heading']); ?></div>
				<?php endif; ?>
			</div>
		</div>

		<?php 
		$order = $settings['post_order'];
		$post_number = $settings['post_number'];
		$wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'portfolio',  'orderby' => 'ID', 'order' => $order));
		$i = 0;
		while ($wp_query -> have_posts()) : $wp_query -> the_post();  
			$project_info = get_post_meta(get_the_ID(),'_cmb_project_info', true);
			$project_subtitle = get_post_meta(get_the_ID(),'_cmb_project_subtitle', true);
			$project_number = get_post_meta(get_the_ID(),'_cmb_project_number', true);
			$i++; 
			?>
			
			<?php if ($i%2==0) { ?>
				<div class="row">
					<div class="col-md-12 mb-120 animate-box" data-animate-effect="fadeInUp">
						<div class="projects2 left">
							<figure>
								<a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" alt=""></a>
							</figure>
							<div class="caption">
								<div class="section-number"><?php echo esc_attr($project_number); ?></div>
								<h6><?php echo esc_attr($project_subtitle); ?></h6>
								<h4><?php the_title();?></h4>
								<p><?php if(isset($nowarch_redux_demo['portfolio_excerpt'])){?>
									<?php echo esc_attr(nowarch_excerpt_2($nowarch_redux_demo['portfolio_excerpt'])); ?>
								<?php }else{?>
									<?php echo esc_attr(nowarch_excerpt_2(25)); }?></p>
									<div class="butn-dark"><a href="<?php the_permalink();?>"><span><?php echo esc_html__( 'View project', 'nowarch' )?> <i class="ti-arrow-right"></i></span></a></div>
								</div>
							</div>
						</div>
					</div>
				<?php }elseif ($i%2==1){ ?>
					<div class="row">
						<div class="col-md-12 mb-120 animate-box" data-animate-effect="fadeInUp">
							<div class="projects2">
								<figure>
									<a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" alt=""></a>
								</figure>
								<div class="caption">
									<div class="section-number"><?php echo esc_attr($project_number); ?></div>
									<h6><?php echo esc_attr($project_subtitle); ?></h6>
									<h4><?php the_title();?></h4>
									<p><?php if(isset($nowarch_redux_demo['portfolio_excerpt'])){?>
										<?php echo esc_attr(nowarch_excerpt_2($nowarch_redux_demo['portfolio_excerpt'])); ?>
									<?php }else{?>
										<?php echo esc_attr(nowarch_excerpt_2(25)); }?></p>
										<div class="butn-dark"><a href="<?php the_permalink();?>"><span><?php echo esc_html__( 'View project', 'nowarch' )?> <i class="ti-arrow-right"></i></span></a></div>
									</div>
								</div>
							</div>
						</div>
					<?php } ?>
				<?php endwhile; ?>
			</div>
		</section>
<?php if (is_admin()) { ?>
<script type="text/javascript">
   var pageSection = jQuery(".bg-img, section");
  pageSection.each(function (indx) {
    if (jQuery(this).attr("data-background")) {
      jQuery(this).css("background-image", "url(" + jQuery(this).data("background") + ")");
    }
  });
   
</script>
<?php }  ?>
	<?php
	}

}
